@@ -178,7 +178,7 @@ class Table:
             for path in given_input:
                 path_to_attribute = path[:-1]
                 attribtue = path[-1]
-                sub_schema = self.__schema_validator.get_sub_schema(path_to_attribute)
+                sub_schema, _ = self.__schema_validator.get_sub_schema(path_to_attribute)
                 if attribtue in sub_schema.get("required", list()):
                     self.custom_exception.removing_required_attribute(attribtue, path_to_attribute)
         else:
@@ -205,6 +205,20 @@ class Table:
         elif len(index_primary) > len(self.indexes[index]):
             self.custom_exception.wrong_primary_key(index_primary)
 
+    def _create_projection_expression(self, attributes_to_get):
+        if isinstance(attributes_to_get, str):
+            attributes_to_get = [attributes_to_get]
+        for i in self.pk:
+            if i not in attributes_to_get:
+                attributes_to_get.append(i)
+        for i, v in enumerate(attributes_to_get):
+            if isinstance(v, list):
+                for vi, value in enumerate(v):
+                    if isinstance(value, int):
+                        v[vi] = f"[{value}]"
+                attributes_to_get[i] = ".".join(v)
+        return ",".join(attributes_to_get)
+
     def describe(self):
         from boto3 import client
 
@@ -214,10 +228,33 @@ class Table:
         )
         return response
 
-    def get(self, **primary_dict):
+    def get(self, attributes_to_get: list = None, **primary_dict):
+        """
+        get item specified with primary_dict
+
+        Parameters
+        ----------
+        attributes_to_get: list, optional
+            specify certain attributes to get
+        primary_dict: dict
+            primary keys for the item to retrieve
+
+        Returns
+        -------
+        dict
+
+        """
         self._primary_key_checker(primary_dict)
 
-        response = self.__table.get_item(Key=primary_dict)
+        get_data = {
+            "Key": primary_dict
+        }
+        if attributes_to_get:
+            get_data.update({"ProjectionExpression": self._create_projection_expression(attributes_to_get)})
+
+        response = self.__table.get_item(
+            **get_data
+        )
 
         if "Item" not in response:
             self.custom_exception.not_found_message(primary_dict)
@@ -274,9 +311,10 @@ class Table:
         paths_to_new_data=None,
         values_per_path=None,
         list_operation: (bool, list, tuple) = False,
-        set_operation: (bool, set) = False
+        set_operation: (bool, set) = False,
+        value_operation: bool = False
     ):
-        expression = "set " if not set_operation else "add "
+        expression = "set " if (value_operation or not set_operation) else "add "
         expression_values = dict()
 
         if not paths_to_new_data or not values_per_path:
@@ -286,6 +324,8 @@ class Table:
             list_operation = [list_operation for i in paths_to_new_data]
         if isinstance(set_operation, bool):
             set_operation = [set_operation for i in paths_to_new_data]
+        if isinstance(value_operation, bool):
+            value_operation = [value_operation for i in paths_to_new_data]
 
         attribute_key_mapping = dict()
         letters_used = 0
@@ -295,6 +335,8 @@ class Table:
                 return f"= list_append({string_path_to_attribute}, :{_value_update_chars[path_no]})"
             if set_operation[path_no]:
                 return f":{_value_update_chars[path_no]}"
+            if value_operation[path_no]:
+                return f"= {string_path_to_attribute} + :{_value_update_chars[path_no]}"
             return f"= :{_value_update_chars[path_no]}"
 
         def update_expression_value():
@@ -399,6 +441,7 @@ class Table:
         create_item_if_non_existent,
         list_operation=False,
         set_operation=False,
+        value_operation=False,
         returns: UpdateReturns = UpdateReturns.NONE,
         new_data=None,
         remove_data=None,
@@ -417,7 +460,7 @@ class Table:
                 expression_value_map,
                 expression_name_map,
                 paths_to_data,
-            ) = self._create_update_expression(new_data, list_operation=list_operation, set_operation=set_operation)
+            ) = self._create_update_expression(new_data, list_operation=list_operation, set_operation=set_operation, value_operation=value_operation)
 
         else:
             # ToDo create condition for attribute still required length if schema contains minItems/minProperties
@@ -664,19 +707,26 @@ class Table:
             returns=returns
         )
 
-    def update_increment(self, path_of_to_increment, condition=None, **primary_dict):
-        #  response = table.update_item(
-        #     Key={
-        #         'year': year,
-        #         'title': title
-        #     },
-        #     UpdateExpression="set path.to.attribute = path.to.attribute + :val",
-        #     ExpressionAttributeValues={
-        #         ':val': decimal.Decimal(1)
-        #     },
-        #     ReturnValues="UPDATED_NEW"        # return the new value of the increased attribute
-        # )
-        raise NotImplemented
+    def update_number_drift(
+            self,
+            drift_values_in_dict: dict,
+            set_new_attribute_if_not_existent=False,
+            create_item_if_non_existent=False,
+            returns: UpdateReturns = UpdateReturns.NONE,
+            condition=None,
+            **primary_dict
+    ):
+        return self.__general_update(
+            **primary_dict,
+            new_data=drift_values_in_dict,
+            require_attributes_already_present=False
+            if set_new_attribute_if_not_existent
+            else True,
+            create_item_if_non_existent=create_item_if_non_existent,
+            value_operation=True,
+            direct_condition=condition,
+            returns=returns
+        )
 
     def put(self, item, overwrite=False):
         self._validate_input(item)
@@ -796,7 +846,13 @@ class Table:
             return {item[self.pk[0]]: item for item in object_list}
         return {(item[self.pk[0]], item[self.pk[1]]): item for item in object_list}
 
-    def index_get(self, index: str, return_as_dict_of_primary_keys: bool = False, **index_keys: dict):
+    def index_get(
+            self,
+            index: str,
+            return_as_dict_of_primary_keys: bool = False,
+            attributes_to_get: list = None,
+            **index_keys: dict
+    ):
         """
         get item from index name with index primary
 
@@ -806,6 +862,8 @@ class Table:
             the name of the index
         index_keys: dict
             dict of the primary_keys
+        attributes_to_get: list, optional
+            specify certain attributes to get
         return_as_dict_of_primary_keys: bool
             if the response shall be as an array (input=False) or as a dictionary of items
              with primary_values as key (input=True)
@@ -820,10 +878,15 @@ class Table:
         self._index_key_checker(index, index_keys)
         expression_array = [Key(k).eq(v) for k, v in index_keys.items()]
         key_condition_expression = expression_array[0] if len(expression_array) == 1 else And(*expression_array)
+        query_data = {
+            "IndexName": index,
+            "Select": SelectReturns.ALL_ATTRIBUTES,
+            "KeyConditionExpression": key_condition_expression
+        }
+        if attributes_to_get:
+            query_data.update({"ProjectionExpression": self._create_projection_expression(attributes_to_get)})
         object_list = self.query(
-            IndexName=index,
-            Select=SelectReturns.ALL_ATTRIBUTES,
-            KeyConditionExpression=key_condition_expression
+            **query_data
         )["Items"]
         if len(object_list) == 0:
             raise FileNotFoundError
