@@ -2,12 +2,14 @@ from unittest import TestCase, skip
 from os import environ as os_environ
 from pathlib import Path
 from os import chdir, getcwd
-from fil_io.json import load_single
+import json
+import sys
 from copy import deepcopy
 from moto import mock_dynamodb2
 from pytest import fixture
 
-test_item = load_single(Path(Path(__file__).parent, "test_data/items/test_item.json"))
+with open(Path(Path(__file__).parent, "test_data/items/test_item.json")) as fi:
+    test_item = json.load(fi)
 test_item_primary = {"primary_partition_key": "some_identification_string"}
 
 
@@ -51,6 +53,9 @@ class TestDynamoDBBase(TestCase):
     actual_cwd = str()
 
     def setUp(self) -> None:
+        for key in list(sys.modules.keys()):
+            if any(key.startswith(i) for i in ["dynamo_db_resource", "test"]):
+                del sys.modules[key]
         os_environ["STAGE"] = "TEST"
         os_environ["AWS_REGION"] = "eu-central-1"
         os_environ["DYNAMO_DB_RESOURCE_SCHEMA_ORIGIN"] = "file"
@@ -63,9 +68,8 @@ class TestDynamoDBBase(TestCase):
             create_dynamo_db_table_from_schema,
         )
 
-        self.raw_schema = load_single(
-            Path(Path(__file__).parent, f"test_data/tables/{self.table_name}.json")
-        )
+        with open(Path(Path(__file__).parent, f"test_data/tables/{self.table_name}.json")) as f:
+            self.raw_schema = json.load(f)
         create_dynamo_db_table_from_schema(self.raw_schema)
 
     def tearDown(self) -> None:
@@ -664,6 +668,51 @@ class TestDynamoDB(TestDynamoDBBase):
             LE.exception.args[0],
         )
 
+    def test_projection_expression(self):
+        from dynamo_db_resource import Table
+        t = Table(self.table_name)
+
+        self.assertEqual(
+            "some_value,primary_partition_key",
+            t._create_projection_expression("some_value")
+        )
+        self.assertEqual(
+            "some_value,primary_partition_key",
+            t._create_projection_expression(["some_value"])
+        )
+        self.assertEqual(
+            "some_value,some_int,primary_partition_key",
+            t._create_projection_expression(["some_value", "some_int"])
+        )
+        self.assertEqual(
+            "some_nested_dict.KEY1,primary_partition_key",
+            t._create_projection_expression([["some_nested_dict", "KEY1"]])
+        )
+        self.assertEqual(
+            "some_array.[0],primary_partition_key",
+            t._create_projection_expression([["some_array", 0]])
+        )
+
+    @skip("issue in moto: ProjectionExpression not working on get_item (#4370)")
+    def test_get_specified_attributes(self):
+        from dynamo_db_resource import Table
+        t = Table(self.table_name)
+
+        response = t.get(
+            attributes_to_get=["some_string", ["some_nested_dict", "KEY1", "subKEY1"], ["some_array", 0]],
+            **test_item_primary
+        )
+        self.assertEqual(len(response), 3)
+
+        self.assertEqual(
+            1,
+            response["some_string"]
+        ),
+        self.assertNotIn(
+            "some_dict",
+            response
+        )
+
     def test_put_item_missing_keys(self):
         item = test_item_primary.copy()
         from dynamo_db_resource import Table
@@ -1059,6 +1108,29 @@ class TestDynamoDB(TestDynamoDBBase):
             ],
         )
 
+    def test_update_integer_drift(self):
+        from dynamo_db_resource import Table, UpdateReturns
+        t = Table(self.table_name)
+        t.put(test_item)
+
+        new_value = t.update_number_drift({"some_int": -1}, returns=UpdateReturns.UPDATED_NEW, **test_item_primary)
+        assert new_value == test_item["some_int"] - 1
+        assert t.get(**test_item_primary)["some_int"] == test_item["some_int"] - 1
+
+    def test_update_nested_float_drift(self):
+        from dynamo_db_resource import Table, UpdateReturns
+        t = Table(self.table_name)
+        t.put(test_item)
+        new_value = t.update_number_drift(
+            {"some_nested_dict": {"KEY1": {"subKEY2": 3.5}}},
+            returns=UpdateReturns.UPDATED_NEW,
+            **test_item_primary
+        )
+        assert new_value == test_item["some_nested_dict"]["KEY1"]["subKEY2"] + 3.5
+        assert t.get(
+            **test_item_primary
+        )["some_nested_dict"]["KEY1"]["subKEY2"] == test_item["some_nested_dict"]["KEY1"]["subKEY2"] +3.5
+
     def test_add_attribute(self):
         added_attribute = {
             "some_nested_dict": {
@@ -1280,23 +1352,6 @@ class TestDynamoDB(TestDynamoDBBase):
             t.get(**test_item_primary)["some_string_set"]
         )
 
-    def test_removing_non_existing_items_from_set(self):
-        from dynamo_db_resource import Table
-
-        t = Table(self.table_name)
-        t.put(test_item)
-        t.add_new_attribute({"some_string_set": {"2", "3", "4", "5"}}, **test_item_primary)
-        with self.assertRaises(KeyError):
-            t.remove_from_set(["some_string_set"], {"7"}, **test_item_primary)
-
-    def test_removing_from_non_existing_set(self):
-        from dynamo_db_resource import Table
-
-        t = Table(self.table_name)
-        t.put(test_item)
-        with self.assertRaises(KeyError):
-            t.remove_from_set(["some_string_set"], {"7"}, **test_item_primary)
-
     def test_remove_attribute(self):
         from dynamo_db_resource import Table
         t = Table(self.table_name)
@@ -1512,7 +1567,8 @@ class TestDynamoDBRangeNIndex(TestDynamoDBBase):
         t = Table(self.table_name)
         file_names = ["test_range_item-1_1.json", "test_range_item-1_2.json", "test_range_item-2_1.json"]
         for file_name in file_names:
-            t.put(load_single(Path(Path(__file__).parent, f"test_data/items/{file_name}")))
+            with open(Path(Path(__file__).parent, f"test_data/items/{file_name}")) as f:
+                t.put(json.load(f))
 
     def test_cast_index_keys(self):
         from dynamo_db_resource import Table
@@ -1566,6 +1622,26 @@ class TestDynamoDBRangeNIndex(TestDynamoDBBase):
             list_response
         )
 
+    def test_get_item_parts_from_index(self):
+        from dynamo_db_resource import Table
+        t = Table(self.table_name)
+
+        response = t.index_get(
+            index="some_string_index",
+            attributes_to_get=["some_int"],
+            **{"some_string": "some_key1"}
+        )
+        self.assertEqual(len(response[0]), 3)
+
+        self.assertEqual(
+            1,
+            response[0]["some_int"]
+        ),
+        self.assertNotIn(
+            "some_string",
+            response[0]
+        )
+
     def test_get_item_from_composite_index(self):
         from dynamo_db_resource import Table
         t = Table(self.table_name)
